@@ -1,22 +1,9 @@
-/* This file is part of the KDE frameworks
- *
- * Copyright (c) 2014 Aurélien Gâteau <agateau@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301  USA
- */
+/*
+    This file is part of the KDE frameworks
+    SPDX-FileCopyrightText: 2014 Aurélien Gâteau <agateau@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 #ifndef KCOLUMNRESIZER_H
 #define KCOLUMNRESIZER_H
 
@@ -25,13 +12,13 @@
 #include <QFormLayout>
 #include <QObject>
 
+#include <memory>
+
 class QEvent;
 class QGridLayout;
 class QLayout;
 class QWidget;
 
-class KColumnResizerPrivate;
-
 /**
  * @class KColumnResizer kcolumnresizer.h KColumnResizer
  *
@@ -119,10 +106,8 @@ protected:
     bool eventFilter(QObject *, QEvent *event) override;
 
 private:
-    KColumnResizerPrivate *const d;
+    std::unique_ptr<class KColumnResizerPrivate> const d;
     Q_DISABLE_COPY(KColumnResizer)
-
-    Q_PRIVATE_SLOT(d, void updateWidth())
 };
 
 #endif /* KCOLUMNRESIZER_H */
